@@ -1,5 +1,3 @@
-// $Id: Anon.cc 7075 2010-09-13 02:39:38Z vern $
-
 #include <stdlib.h>
 #include <unistd.h>
 #include <assert.h>
@@ -7,7 +5,6 @@
 
 #include "util.h"
 #include "net_util.h"
-#include "md5.h"
 #include "Anon.h"
 #include "Val.h"
 #include "NetVar.h"
@@ -17,7 +14,7 @@ AnonymizeIPAddr* ip_anonymizer[NUM_ADDR_ANONYMIZATION_METHODS] = {0};
 
 static uint32 rand32()
 	{
-	return ((random() & 0xffff) << 16) | (random() & 0xffff);
+	return ((bro_random() & 0xffff) << 16) | (bro_random() & 0xffff);
 	}
 
 // From tcpdpriv.
@@ -85,7 +82,8 @@ int AnonymizeIPAddr::PreserveNet(ipaddr32_t input)
 
 ipaddr32_t AnonymizeIPAddr_Seq::anonymize(ipaddr32_t /* input */)
 	{
-	return htonl(seq++);
+	++seq;
+	return htonl(seq);
 	}
 
 ipaddr32_t AnonymizeIPAddr_RandomMD5::anonymize(ipaddr32_t input)
@@ -102,9 +100,9 @@ ipaddr32_t AnonymizeIPAddr_RandomMD5::anonymize(ipaddr32_t input)
 	}
 
 
-// This code is from "On the Design and Performance of Prefix-Preserving 
+// This code is from "On the Design and Performance of Prefix-Preserving
 // IP Traffic Trace Anonymization", by Xu et al (IMW 2001)
-// 
+//
 // http://www.imconf.net/imw-2001/proceedings.html
 
 ipaddr32_t AnonymizeIPAddr_PrefixMD5::anonymize(ipaddr32_t input)
@@ -150,16 +148,20 @@ void AnonymizeIPAddr_A50::init()
 	special_nodes[0].input = special_nodes[0].output = 0;
 	special_nodes[1].input = special_nodes[1].output = 0xFFFFFFFF;
 
+	method = 0;
 	before_anonymization = 1;
+	new_mapping = 0;
 	}
 
 int AnonymizeIPAddr_A50::PreservePrefix(ipaddr32_t input, int num_bits)
 	{
-	DEBUG_MSG("%s/%d\n", dotted_addr(input), num_bits);
+	DEBUG_MSG("%s/%d\n",
+			IPAddr(IPv4, &input, IPAddr::Network).AsString().c_str(),
+			num_bits);
 
 	if ( ! before_anonymization )
 		{
-		run_time("prefix perservation specified after anonymization begun");
+		reporter->Error("prefix perservation specified after anonymization begun");
 		return 0;
 		}
 
@@ -206,7 +208,7 @@ AnonymizeIPAddr_A50::Node* AnonymizeIPAddr_A50::new_node_block()
 	int block_size = 1024;
 	Node* block = new Node[block_size];
 	if ( ! block )
-		internal_error("out of memory!");
+		reporter->InternalError("out of memory!");
 
 	blocks.push_back(block);
 
@@ -258,7 +260,7 @@ ipaddr32_t AnonymizeIPAddr_A50::make_output(ipaddr32_t old_output, int swivel) c
 AnonymizeIPAddr_A50::Node* AnonymizeIPAddr_A50::make_peer(ipaddr32_t a, Node* n)
 	{
 	if ( a == 0 || a == 0xFFFFFFFFU )
-		internal_error("0.0.0.0 and 255.255.255.255 should never get into the tree");
+		reporter->InternalError("0.0.0.0 and 255.255.255.255 should never get into the tree");
 
 	// Become a peer.
 	// Algorithm: create two nodes, the two peers.  Leave orig node as
@@ -341,7 +343,7 @@ AnonymizeIPAddr_A50::Node* AnonymizeIPAddr_A50::find_node(ipaddr32_t a)
 			}
 		}
 
-	internal_error("out of memory!");
+	reporter->InternalError("out of memory!");
 	return 0;
 	}
 
@@ -379,24 +381,24 @@ ipaddr32_t anonymize_ip(ipaddr32_t ip, enum ip_addr_anonymization_class_t cl)
 	}
 
 	ipaddr32_t new_ip = 0;
-		
+
 	if ( preserve_addr && preserve_addr->Lookup(&addr) )
 		new_ip = ip;
 
 	else if ( method >= 0 && method < NUM_ADDR_ANONYMIZATION_METHODS )
 		{
-		if ( method == KEEP_ORIG_ADDR ) 
+		if ( method == KEEP_ORIG_ADDR )
 			new_ip = ip;
 
 		else if ( ! ip_anonymizer[method] )
-			internal_error("IP anonymizer not initialized");
+			reporter->InternalError("IP anonymizer not initialized");
 
 		else
 			new_ip = ip_anonymizer[method]->Anonymize(ip);
 		}
 
 	else
-		internal_error("invalid IP anonymization method");
+		reporter->InternalError("invalid IP anonymization method");
 
 #ifdef LOG_ANONYMIZATION_MAPPING
 	log_anonymization_mapping(ip, new_ip);
